SlowlogGetInfo class

SlowlogGetInfo

Constructors

SlowlogGetInfo({required int id, required int timestamp, required int duration, required List<String>? command, required String? client, required String? extraInfo})
SlowlogGetInfo

Properties

client String?
客户端
final
command List<String>?
命令
final
duration int
命令执行时长
final
extraInfo String?
额外信息
final
hashCode int
The hash code for this object.
no setterinherited
id int
命令ID
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
命令执行时间
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited